Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2)

Unified Diff: pkg/analysis_server/lib/src/analysis_server.dart

Issue 304923003: Rename PubFolder and update comments. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/src/analysis_server.dart
diff --git a/pkg/analysis_server/lib/src/analysis_server.dart b/pkg/analysis_server/lib/src/analysis_server.dart
index 327153f0be41a9cc8fb31a0c815bd64c9a1bc793..3554ec898f71601bece7c6a76efacfd994a75073 100644
--- a/pkg/analysis_server/lib/src/analysis_server.dart
+++ b/pkg/analysis_server/lib/src/analysis_server.dart
@@ -35,9 +35,10 @@ class AnalysisServerContextDirectoryManager extends ContextDirectoryManager {
: super(resourceProvider);
void addContext(Folder folder, File pubspecFile) {
- PubFolder pubFolder = new PubFolder(analysisServer.defaultSdk, folder, pubspecFile);
- analysisServer.folderMap[folder] = pubFolder;
- analysisServer.addContextToWorkQueue(pubFolder.context);
+ ContextDirectory contextDirectory = new ContextDirectory(
+ analysisServer.defaultSdk, folder, pubspecFile);
+ analysisServer.folderMap[folder] = contextDirectory;
+ analysisServer.addContextToWorkQueue(contextDirectory.context);
}
void applyChangesToContext(Folder contextFolder, ChangeSet changeSet) {
@@ -112,9 +113,9 @@ class AnalysisServer {
DartSdk defaultSdk = SHARED_SDK;
/**
* A table mapping [Folder]s to the [PubFolder]s associated with them.
*/
- final Map<Folder, PubFolder> folderMap = <Folder, PubFolder>{};
+ final Map<Folder, ContextDirectory> folderMap = <Folder, ContextDirectory>{};
/**
* The context identifier used in the last status notification.
@@ -433,16 +434,17 @@ class AnalysisService extends Enum2<AnalysisService> {
/**
- * Instances of [PubFolder] represents a [Folder] with a Pub `pubspec.yaml`.
+ * Instances of [ContextDirectory] represents a [Folder] associated with an
+ * analysis context. The folder may or may not contain a Pub `pubspec.yaml`.
*
* TODO(scheglov) implement complete projects/contexts semantics.
*
* This class is intentionally simplified to serve as a base to start working
* on services while work on complete semantics is being done in parallel.
*/
-class PubFolder {
+class ContextDirectory {
/**
- * The root [Folder] of this [PubFolder].
+ * The root [Folder] of this [ContextDirectory].
*/
final Folder _folder;
@@ -456,7 +458,7 @@ class PubFolder {
*/
AnalysisContext _context;
- PubFolder(DartSdk sdk, this._folder, this._pubspecFile) {
+ ContextDirectory(DartSdk sdk, this._folder, this._pubspecFile) {
// create AnalysisContext
_context = AnalysisEngine.instance.createAnalysisContext();
// TODO(scheglov) replace FileUriResolver with an Resource based resolver
@@ -112,9 +113,9 @@ class AnalysisServer {
DartSdk defaultSdk = SHARED_SDK;
/**
- * A table mapping [Folder]s to the [PubFolder]s associated with them.
+ * A table mapping [Folder]s to the [ContextDirectory]s associated with them.
*/
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698